yakumo.neutron.v2.network.Resource

Package yakumo :: Package neutron :: Package v2 :: Module network :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for networks in Networking V2 API

Instance Methods | [hide private]
None |
update(self, name=`'``__UNDEF__``'`, is_shared=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`, is_external=`'``__UNDEF__``'`, is_port_security_enabled=`'``__UNDEF__``'`, segments=`'``__UNDEF__``'`, provider_physical_network=`'``__UNDEF__``'`, provider_network_type=`'``__UNDEF__``'`, provider_segmentation_id=`'``__UNDEF__``'`) Update properties of a network | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| _stable_state = ``[``'``ACTIVE``'``,` `'``DOWN``'``,` `'``INACTIVE``'``,` `'``ERROR``'``]``
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, name=`'``__UNDEF__``'`, is_shared=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`, is_external=`'``__UNDEF__``'`, is_port_security_enabled=`'``__UNDEF__``'`, segments=`'``__UNDEF__``'`, provider_physical_network=`'``__UNDEF__``'`, provider_network_type=`'``__UNDEF__``'`, provider_segmentation_id=`'``__UNDEF__``'`) | source code
Update properties of a network Parameters: `name` (str) - Network name `is_shared` (bool) - Whether the network is shared `is_enabled` (bool) - Whether the network is enabled `is_external` (bool) - Wehter the network is external `is_port_security_enabled` (bool) - Whether the network is secured `segments` (str) - Segments `provider_physical_network` (str) - (Provider) physical network `provider_network_type` (str) - (Provider) network type `provider_segmentation_id` (int) - (Provider) segmentation ID Returns: None Overrides: base.Resource.update